@@ -171,7 +171,7 @@ class EManafa(Service):
 
 	def __extractPowerProfile(self, filename):
 		# extracting power_profile.xml from device
-		res, suc, _ = execute_shell_command("adb pull /system/framework/framework-res.apk %s" % self.resources_dir)
+		res, suc, v = execute_shell_command("adb pull /system/framework/framework-res.apk %s" % self.resources_dir)
 		if res==0:
 			cmd = """java -jar {res_dir}/apktool_2.4.0.jar d -s {res_dir}/framework-res.apk -f -o {res_dir}/out_jar_dir/""".format(res_dir=self.resources_dir)
 			res, suc, v = execute_shell_command(cmd)
